# Financial Conditions and Macroeconomic Downside Risks in the Euro Area

Computer codes to replicate "Financial Conditions and Macroeconomic Downside Risks in the Euro Area", European Economic Review (April 2022)
by Stéphane LHUISSIER

## Requirements

[Matlab](https://mathworks.com). I used Matlab R2021a.

## Data
Go to folder 'data', and run 'bvar_qdata.m' to generate the database 'ea_data_99q1_19q4.txt'.

## Optimization, MCMC and main results

- (1) To find the posteror mode of a model, run 'run_optimization.m'. There are six models under consideration : 
    a) benchmark : MS skew-normal model with time-varying transition probabilities conditional on GDP and CISS
    b) onlyGDP   : MS skew-normal model with time-varying transition probabilities conditional only on GDP
    c) ftp       : MS skew-normal model with fixed transition probabilities
    d) normal    : Standard Markov-switching Gaussian model with fixed time-varying probabilities

    e) loose025 : MS skew-normal model with time-varying transition probabilities conditional on GDP and CISS with looser prior, 0.25 (see Robustness, Section VII.1)
    d) loose050 : MS skew-normal model with time-varying transition probabilities conditional on GDP and CISS with looser prior, 0.50 (see Robustness, Section VII.1)

    Modify line 25 to pick the model of interest. The results will be stored in the 'posterior_mode.mat' and 'posterior_mode.xlsx' files.

- (2) To run the Gibbs sampler, run 'run_gibbs.m'. Several options are available (number of draws, number of burn-in, etc...). The file also computes the WAIC criteria.
The results will be stored in the 'gibbs_draws.mat' and 'Gibbs_moments68.xlsx' files, and WAIC.mat.

- (3) To generate the main results of Section V ("Time variation in GDP growth distribution"), run 'run_insample_statistics'. The results will be stored in the 'insample_stats'.mat' file. 

## Out-of-Sample Forecast Procedure

To conduct out-of-sample backtesting exercises by using the proposed methodology in real time, you need to 

- (1) run 'run_realtime_optimization' to find the posterior mode recursively (i.e., expanding the estimation sample, one quarter at a time, until the end of the sample).

- (2) run 'run_realtime_gibbs' to run the Gibbs sampler recursively. You need to choose the number of workers (which depends on your machine) because the code is parallelized to speed up the algorithm.

- (3) run 'run_realtime_forecast' to produce out-of-sample forecasts. Also here, the code is parallelized.

All results will be stored in the folder "real-time/".

## Robustness

To generate the results of 
- Section VII.1. (Prior sensitivity), see above.
- Section VII.2. (Synchronized vs independent chains), go to folder 'synchronized' and run 'run_optimization' and 'run_gibbs' files.
- Section VII.3. (In-sample vs out-of-sample forecasts.), run 'App_Tab8' and 'App_Fig12' files. 


## Figures and Tables

Before displaying figures and tables, you need to run files mentioned above.

Go to the folder 'figures':
(1) Run 'gen_Fig1.m' to display output growth and CISS (Figure 1)
(2) Run 'gen_Fig2.m' to display the density functions across regimes (Figure 2) 
(3) Run 'gen_Fig3.m' to generate filtered probabilities (Figure 3).
(4) Run 'gen_Fig4.m' to display moments (Figure 4)
(5) Run 'gen_Fig5.m' to report expected shortfall and probability of recession (Figur 5)
(6) Run 'gen_Fig6.m' to display predictive density around the Great Recession (Figure 6)
(7) Run 'gen_Fig7.m' to display Probability Integral Transforms (PITs) (Figure 7)
(8) Run 'gen_Fig8.m' to report predictive densities around the sovereign debt crisis (Figure 8)

Go to the folder 'tables':
(1) Run 'gen_Tab1.m' to display prior and posterior distributions in a LateX format (Table 1)
(2) Run 'gen_Tab2.m' for the estimated transition matrices in a LateX format (Table 2)
(3) Run 'gen_Tab3.m' to report WAIC information criteria in a LateX format (Table 3)
(4) Run 'gen_Tab4.m'  for the accuracy of out-of-sample forecasts in a LateX format (Table 4)

You can also generate figures and tables of the online appendix.

## Library

Folder "library" contains all other Matlab functions. Folders "skn-library" come from [Adelchi Azzalini](http://azzalini.stat.unipd.it/SN/)'s library.

## Corrigendum

File 'run_statistics.m' has been modified in August 2022 to properly compute some metrics. 

## Contact

Please let me know if you find any errors or problems with the files: stephane.lhuissier@hotmail.com (Banque de France)