clear variables; clc;


% beginning of sample
Binyr = datetime('01/01/1999','InputFormat','dd/MM/yyyy');
% end of sample
Endyr = datetime('01/10/2019','InputFormat','dd/MM/yyyy');
% name of data file
fname='bvar_qdata.xls';
% path of data file
fpath='';
% load data
[data_numeric, data_text] = xlsread(fullfile(fpath,fname),'quarterly');
% recover date
list.data_date = datetime(data_text(3:end,1),'InputFormat','dd/MM/yyyy');
% time series of dates
qdates = list.data_date(find(list.data_date==Binyr):find(list.data_date==Endyr));

RGDP   = (log(data_numeric(find(list.data_date==Binyr):find(list.data_date==Endyr),1))-log(data_numeric(find(list.data_date==Binyr)-1:find(list.data_date==Endyr)-1,1)))*100;
CS     = data_numeric(find(list.data_date==Binyr):find(list.data_date==Endyr),2)/100; % p.p
EBP    = data_numeric(find(list.data_date==Binyr):find(list.data_date==Endyr),3)/100; % p.p
G10Y   = data_numeric(find(list.data_date==Binyr):find(list.data_date==Endyr),4);
R3M    = data_numeric(find(list.data_date==Binyr):find(list.data_date==Endyr),5);
VSTOXX = data_numeric(find(list.data_date==Binyr):find(list.data_date==Endyr),6);
EONIA  = data_numeric(find(list.data_date==Binyr):find(list.data_date==Endyr),7);

CISS         = data_numeric(find(list.data_date==Binyr):find(list.data_date==Endyr),8);
CISS_BOND    = data_numeric(find(list.data_date==Binyr):find(list.data_date==Endyr),9);
CISS_EQUITY  = data_numeric(find(list.data_date==Binyr):find(list.data_date==Endyr),10);
CISS_INTERM  = data_numeric(find(list.data_date==Binyr):find(list.data_date==Endyr),11);
CISS_FOREIGN = data_numeric(find(list.data_date==Binyr):find(list.data_date==Endyr),12);
CISS_MONEY   = data_numeric(find(list.data_date==Binyr):find(list.data_date==Endyr),13);

TS     = G10Y - R3M;
adjCS  = CS - EBP;

% save
T = table(datetime(qdates,'Format','M/dd/y'), ...
     RGDP,CS,adjCS,EBP,TS,VSTOXX,EONIA,CISS,CISS_BOND,CISS_EQUITY,CISS_INTERM,CISS_FOREIGN,CISS_MONEY, ...
     'VariableNames',{ 'DATES','RGDP','CS','adjCS','EBP','TS','VSTOXX','EONIA','CISS', ...
        'CISS_BOND','CISS_EQUITY','CISS_INTERM','CISS_FOREIGN','CISS_MONEY'} );
 
writetable(T, 'ea_data_99q1_19q4.txt','Delimiter',' ')

figure;
subplot(3,4,1)
plot(qdates,RGDP)
box on; grid on;
t=title('Real GDP growth');
set(t, 'horizontalAlignment', 'left');
set(t, 'units', 'normalized');
get(t, 'position');
set(t, 'position', [0 1 0]);
xlabel('years')
xlim([qdates(1) qdates(end)])
subplot(3,4,2)
plot(qdates,CS)
box on; grid on;
t=title('Credit spread');
set(t, 'horizontalAlignment', 'left');
set(t, 'units', 'normalized');
get(t, 'position');
set(t, 'position', [0 1 0]);
xlabel('years')
xlim([qdates(1) qdates(end)])
subplot(3,4,3)
plot(qdates,adjCS)
t=title('Adjusted credit spread');
set(t, 'horizontalAlignment', 'left');
set(t, 'units', 'normalized');
get(t, 'position');
set(t, 'position', [0 1 0]);
xlabel('years')
xlim([qdates(1) qdates(end)])
box on; grid on;
subplot(3,4,4)
plot(qdates,EBP)
t=title('Excess bond premium');
set(t, 'horizontalAlignment', 'left');
set(t, 'units', 'normalized');
get(t, 'position');
set(t, 'position', [0 1 0]);
xlabel('years')
xlim([qdates(1) qdates(end)])
box on; grid on;
subplot(3,4,5)
plot(qdates,TS)
box on; grid on;
t=title('Term spread');
set(t, 'horizontalAlignment', 'left');
set(t, 'units', 'normalized');
get(t, 'position');
set(t, 'position', [0 1 0]);
xlabel('years')
xlim([qdates(1) qdates(end)])
subplot(3,4,6)
plot(qdates,VSTOXX)
box on; grid on;
t=title('VSTOXX');
set(t, 'horizontalAlignment', 'left');
set(t, 'units', 'normalized');
get(t, 'position');
set(t, 'position', [0 1 0]);
xlabel('years')
xlim([qdates(1) qdates(end)])
subplot(3,4,7)
plot(qdates,CISS)
box on; grid on;
t=title('CISS');
set(t, 'horizontalAlignment', 'left');
set(t, 'units', 'normalized');
get(t, 'position');
set(t, 'position', [0 1 0]);
xlabel('years')
xlim([qdates(1) qdates(end)])
subplot(3,4,8)
plot(qdates,CISS_EQUITY)
box on; grid on;
t=title('CISS, EQUITY MARKET');
set(t, 'horizontalAlignment', 'left');
set(t, 'units', 'normalized');
get(t, 'position');
set(t, 'position', [0 1 0]);
xlabel('years')
xlim([qdates(1) qdates(end)])
subplot(3,4,9)
plot(qdates,CISS_BOND)
box on; grid on;
t=title('CISS, BOND MARKET');
set(t, 'horizontalAlignment', 'left');
set(t, 'units', 'normalized');
get(t, 'position');
set(t, 'position', [0 1 0]);
xlabel('years')
xlim([qdates(1) qdates(end)])
subplot(3,4,10)
plot(qdates,CISS_INTERM)
box on; grid on;
t=title('CISS, FINANCIAL INTERMEDIARIES');
set(t, 'horizontalAlignment', 'left');
set(t, 'units', 'normalized');
get(t, 'position');
set(t, 'position', [0 1 0]);
xlabel('years')
xlim([qdates(1) qdates(end)])
subplot(3,4,11)
plot(qdates,CISS_FOREIGN)
box on; grid on;
t=title('CISS, FOREIGN EXCHANGE MARKET');
set(t, 'horizontalAlignment', 'left');
set(t, 'units', 'normalized');
get(t, 'position');
set(t, 'position', [0 1 0]);
xlabel('years')
xlim([qdates(1) qdates(end)])
subplot(3,4,12)
plot(qdates,CISS_MONEY)
box on; grid on;
t=title('CISS, MONEY MARKET');
set(t, 'horizontalAlignment', 'left');
set(t, 'units', 'normalized');
get(t, 'position');
set(t, 'position', [0 1 0]);
xlabel('years')
xlim([qdates(1) qdates(end)])
