
clear variables; close all; clc;

addpath('../library/')

results_root = '../results';
model_name   = [{'benchmark'},{'loose025'},{'loose050'}];

% probability bands
p = [5 16 50 68 95];

% retrieve results
model = cell(length(model_name),1);
for i=1:length(model_name)
    model{i} = load([results_root,'/models/',model_name{i},'/insample_stats.mat'],'samples_EsfST','samples_PrRec','Dat');
end
model = [model{1:length(model_name)}];

samples_EsfST  = cat(3,model.samples_EsfST);
samples_PrRec  = cat(3,model.samples_PrRec);

% date
Dat = model(1).Dat;

% sample size
T = length(Dat);

% memory allocation
quan_EsfST    = NaN(length(p),T,length(model_name));
quan_PrRec    = NaN(length(p),T,length(model_name));

for i=1:length(model_name)
    quan_EsfST(:,:,i) = prctile(samples_EsfST(:,:,i),p);
    quan_PrRec(:,:,i) = prctile(samples_PrRec(:,:,i),p);
end

make_it_tight = true;                     % GAP        LOWER UPPER  LEFT RIGHT
subplot = @(m,n,p) subtightplot (m, n, p, [0.14 0.07], [0.12 0.07], [0.04 0.02]);
if ~make_it_tight,  clear subplot;  end

figure;
subplot(1,2,1)
a=quan_EsfST(1,:,1);
b=quan_EsfST(5,:,1);
c=quan_EsfST(2,:,1);
d=quan_EsfST(4,:,1);
x=Dat;
aa=area([datetime('01/2008','InputFormat','MM/yyyy') datetime('06/2009','InputFormat','MM/yyyy')], [30 30],-10);
hold on
bb=area([datetime('09/2011','InputFormat','MM/yyyy') datetime('01/2013','InputFormat','MM/yyyy')], [30 30],-10);
set(aa,'FaceColor',[255/255 250/255 205/255], 'EdgeColor', 'y')
set(bb,'FaceColor',[255/255 250/255 205/255], 'EdgeColor', 'y')
hold on
[az1,~]=jbfill(x,a,b,[0, 0.4470, 0.7410],[0, 0.4470, 0.7410],0,0.3);
hold on
[az2,~]=jbfill(x,c,d,[0, 0.4470, 0.7410],[0, 0.4470, 0.7410],0,0.6);
hold on
p1=plot(Dat,quan_EsfST(3,:,1),'LineWidth',1.0,'Color','k');
hold on
p2=plot(Dat,quan_EsfST(3,:,2),'LineWidth',1.0,'Color',[0.8500, 0.3250, 0.0980],'LineStyle','--');
hold on
p3=plot(Dat,quan_EsfST(3,:,3),'LineWidth',1.0,'Color',[0.9290, 0.6940, 0.1250],'LineStyle','-.');
ylim([-8 1])
%
box on; grid on;
xlabel('years')
t=title('Panel A. Expected Shortfall');
set(t, 'horizontalAlignment', 'left')
set(t, 'units', 'normalized')
set(t, 'position', [0 1 0])
lgd=legend([p1,az1,az2,p2,p3],'baseline (median)','baseline (90% error bands)', 'baseline (68% error bands)','tightness prior = 0.25 (median)','tightness prior = 0.50 (median)','Location','SouthEast');

subplot(1,2,2)
a=quan_PrRec(1,:,1);
b=quan_PrRec(5,:,1);
c=quan_PrRec(2,:,1);
d=quan_PrRec(4,:,1);
x=Dat;
aa=area([datetime('01/2008','InputFormat','MM/yyyy') datetime('06/2009','InputFormat','MM/yyyy')], [30 30],-10);
hold on
bb=area([datetime('09/2011','InputFormat','MM/yyyy') datetime('01/2013','InputFormat','MM/yyyy')], [30 30],-10);
set(aa,'FaceColor',[255/255 250/255 205/255], 'EdgeColor', 'y')
set(bb,'FaceColor',[255/255 250/255 205/255], 'EdgeColor', 'y')
hold on
[az1,~]=jbfill(x,a,b,[0, 0.4470, 0.7410],[0, 0.4470, 0.7410],0,0.3);
hold on
[az2,~]=jbfill(x,c,d,[0, 0.4470, 0.7410],[0, 0.4470, 0.7410],0,0.6);
hold on
plot(Dat,quan_PrRec(3,:,1),'LineWidth',1.0,'Color','k');
hold on
p2=plot(Dat,quan_PrRec(3,:,2),'LineWidth',1.0,'Color',[0.8500, 0.3250, 0.0980],'LineStyle','--');
hold on
p3=plot(Dat,quan_PrRec(3,:,3),'LineWidth',1.0,'Color',[0.9290, 0.6940, 0.1250],'LineStyle','-.');
%
box on; grid on;
xlabel('years')
ylim([-0.05 1.05])
t=title('Panel B. Probability of recession');
set(t, 'horizontalAlignment', 'left')
set(t, 'units', 'normalized')
set(t, 'position', [0 1 0])


set(gcf,'PaperUnits','inches');
set(gcf,'PaperSize',[6.5 4]);
set(gcf,'PaperPositionMode','manual');
set(gcf,'PaperPosition',[0 0 6.5 4]);

set(gcf,'renderer','painters');
eval('print -dpdf pdf/App_Fig10');