
clear variables; clc;

addpath('../library')

% Models
model_name    = [{'benchmark'},{'onlyGDP'},{'ftp'}];
model_texname = [{'Panel A. MS skn with GDP and CISS'},{'Panel B. MS skn with GDP'},{'Panel C. MS skn'}];

% Probabilities
Pr = cell(length(model_name),1);
for i=1:length(model_name)
    Pr{i} = load(['../synchronized/results/models/',model_name{i},'/gibbs_draws.mat'],'Pr_location');
end

Pr = [Pr{1:length(model_name)}];
Pr = cat(3,Pr.Pr_location);

% Date
BinDate = datetime('04/1999','InputFormat','MM/yyyy');
EndDate = datetime('10/2019','InputFormat','MM/yyyy');
Date    = BinDate:calquarters(1):EndDate;

% Figure
make_it_tight = true;                     % GAP        LOWER UPPER  LEFT RIGHT
subplot = @(m,n,p) subtightplot (m, n, p, [0.08 0.05], [0.20 0.10], [0.05 0.01]);
if ~make_it_tight,  clear subplot;  end

figure;
for i=1:length(model_name)
    subplot(1,3,i)
    a=area([datetime('01/2008','InputFormat','MM/yyyy') datetime('06/2009','InputFormat','MM/yyyy')], [30 30],-10);
    hold on
    b=area([datetime('07/2011','InputFormat','MM/yyyy') datetime('01/2013','InputFormat','MM/yyyy')], [30 30],-10);
    set(a,'FaceColor',[255/255 250/255 205/255], 'EdgeColor', 'y')
    set(b,'FaceColor',[255/255 250/255 205/255], 'EdgeColor', 'y')
    cc=plot(Date,Pr(:,1,i),'LineWidth', 1.3,'color',[0 0.4470 0.7410]);
    ylabel('prob.')
    xticks(datetime('01/1998','InputFormat','MM/yyyy'):calquarters(8):datetime('12/2020','InputFormat','MM/yyyy'))
    xlabel('years')
    t=title(model_texname{i});
    set(t, 'horizontalAlignment', 'left')
    set(t, 'units', 'normalized')
    h = get(t, 'position');
    set(t, 'position', [0 1 0])
    ylim([-0.05 1.05])
    box on
    grid on
    ylabel({'Prob.'})
    xtickangle(45)
end

set(gcf,'PaperUnits','inches');
set(gcf,'PaperSize',[9 3]);
set(gcf,'PaperPositionMode','manual');
set(gcf,'PaperPosition',[0 0 9 3]);

set(gcf,'renderer','painters');
eval('print -dpdf pdf/App_Fig11');
