
clear variables; close all; clc;

addpath('../library/')

results_root = '../results';

% percentile
p = [5 16 50 84 95];

% h-step-ahead forecast
h = 1;                           % Forecast horizon (set to [] if h-step-ahead forecast not desired)
numdraw_h = 5e3;                 % Number of posterior parameter draws to consider

% Beginning of OOS Foreacasting
IntDat    = datetime('04/01/2010','InputFormat','MM/dd/yyyy');

% End of OOS FOrecasting
EndDat    = datetime('10/01/2019','InputFormat','MM/dd/yyyy');

% Time Series of OOS Estimation Date
DatRT     = IntDat:calquarters(1):EndDat;

% Time Series of OOS Date
oos_Dat       = DatRT(1:end-h);

% In-sample Results
is_benchmark=load([results_root,'/models/benchmark/insample_stats.mat'],'samples_quint','Dat');
is_onlyGDP=load([results_root,'/models/onlyGDP/insample_stats.mat'],'samples_quint');
is_ftp=load([results_root,'/models/ftp/insample_stats.mat'],'samples_quint');

is_benchmark_quint = mean(is_benchmark.samples_quint,3)';
is_onlyGDP_quint = mean(is_onlyGDP.samples_quint,3)';
is_ftp_quint = mean(is_ftp.samples_quint,3)';

is_Dat = is_benchmark.Dat;

% Out-of-sample Results
oos_benchmark=struct;
oos_onlyGDP=struct;
oos_ftp=struct;

oos_benchmark.samples_quint=nan(numdraw_h,length(p),length(oos_Dat));
oos_onlyGDP.samples_quint=nan(numdraw_h,length(p),length(oos_Dat));
oos_ftp.samples_quint=nan(numdraw_h,length(p),length(oos_Dat));

for i=1:length(oos_Dat)
    
    % benchmark
    oos_benchmark_foreh = load([results_root,'/models/benchmark/real-time/outofsample/',datestr(DatRT(i)),'.mat'],'samples_quint');
    oos_benchmark.samples_quint(:,:,i) = oos_benchmark_foreh.samples_quint;
    
    % only GDP
    oos_onlyGDP_foreh = load([results_root,'/models/onlyGDP/real-time/outofsample/',datestr(DatRT(i)),'.mat'],'samples_quint');
    oos_onlyGDP.samples_quint(:,:,i) = oos_onlyGDP_foreh.samples_quint;

    % ftp
    oos_ftp_foreh = load([results_root,'/models/ftp/real-time/outofsample/',datestr(DatRT(i)),'.mat'],'samples_quint');
    oos_ftp.samples_quint(:,:,i) = oos_ftp_foreh.samples_quint;
    
end

oos_benchmark_quint = squeeze(mean(oos_benchmark.samples_quint));
oos_onlyGDP_quint = squeeze(mean(oos_onlyGDP.samples_quint));
oos_ftp_quint = squeeze(mean(oos_ftp.samples_quint));

make_it_tight = true;                     % GAP        LOWER UPPER  LEFT RIGHT
subplot = @(m,n,p) subtightplot (m, n, p, [0.08 0.08], [0.105 0.04], [0.08 0.01]);
if ~make_it_tight,  clear subplot;  end

figure;
subplot(1,1,1)
aa=area([datetime('01/2008','InputFormat','MM/yyyy') datetime('06/2009','InputFormat','MM/yyyy')], [30 30],-10);
hold on
bb=area([datetime('09/2011','InputFormat','MM/yyyy') datetime('01/2013','InputFormat','MM/yyyy')], [30 30],-10);
set(aa,'FaceColor',[255/255 250/255 205/255], 'EdgeColor', 'y')
set(bb,'FaceColor',[255/255 250/255 205/255], 'EdgeColor', 'y')
a=is_benchmark_quint(1,:);
b=is_benchmark_quint(5,:);
c=is_benchmark_quint(2,:);
d=is_benchmark_quint(4,:);
[az1,~]=jbfill(is_Dat,a,b,[0, 0.4470, 0.7410],[0, 0.4470, 0.7410],0,0.3);
[az2,~]=jbfill(is_Dat,c,d,[0, 0.4470, 0.7410],[0, 0.4470, 0.7410],0,0.6);
aa=plot(is_Dat(find(is_Dat==oos_Dat(1))+1:end),oos_benchmark_quint(1,:),'LineStyle','-.','color',[0.8500, 0.3250, 0.0980],'Linewidth',1);
hold on
plot(is_Dat(find(is_Dat==oos_Dat(1))+1:end),oos_benchmark_quint(2,:),'LineStyle',':','color',[0.8500, 0.3250, 0.0980],'Linewidth',1.5);
hold on
p2=plot(is_Dat(find(is_Dat==oos_Dat(1))+1:end),oos_benchmark_quint(3,:),'LineStyle','-','color',[0.8500, 0.3250, 0.0980],'Linewidth',1);
hold on
p1=plot(is_Dat,is_benchmark_quint(3,:),'LineStyle','-','color',[0, 0.4470, 0.7410],'Linewidth',1);
hold on
p3=plot(is_Dat(find(is_Dat==oos_Dat(1))+1:end),oos_benchmark_quint(4,:),'LineStyle',':','color',[0.8500, 0.3250, 0.0980],'Linewidth',1.5);
p4=plot(is_Dat(find(is_Dat==oos_Dat(1))+1:end),oos_benchmark_quint(5,:),'LineStyle','-.','color',[0.8500, 0.3250, 0.0980],'Linewidth',1);
ylim([min([is_benchmark_quint(:);oos_benchmark_quint(:)]) max([is_benchmark_quint(:);oos_benchmark_quint(:)])])
box on; grid on;
xlabel('years')
legend([p1,az1,az2,p2,p3,p4],'In-sample (median)','In-sample (90% bands)','In-sample (68% bands)','Out-of-sample (median)','Out-of-sample (90% bands)','Out-of-sample (68% bands)','Location','SouthEast')

set(gcf,'PaperUnits','inches');
set(gcf,'PaperSize',[6.5 5]);
set(gcf,'PaperPositionMode','manual');
set(gcf,'PaperPosition',[0 0 6.5 5]);

set(gcf,'renderer','painters');
eval('print -dpdf pdf/App_Fig12');

