%%%
clear variables; clc;

addpath('../library/')

yt_str     = {'RGDP'};
zt_str     = {'CISS'};

data_file = 'ea_data_99q1_19q4.txt'; 
newData   = importdata(['../data/',data_file]);

varnames  = newData.textdata(1,2:end);
yt        = newData.data(:,strcmp(yt_str,varnames));
zt        = newData.data(:,strcmp(zt_str,varnames));

dateBin = datetime('01/1999','InputFormat','QQ/yyyy');
dateEnd = datetime('04/2019','InputFormat','QQ/yyyy');
qdates   = dateBin:calquarters(1):dateEnd;


make_it_tight = true;                     % GAP        LOWER UPPER  LEFT RIGHT
subplot = @(m,n,p) subtightplot (m, n, p, [0.08 0.08], [0.105 0.03], [0.08 0.09]);
if ~make_it_tight,  clear subplot;  end

figure
subplot(1,1,1)
yyaxis left
a=area([datetime('01/2008','InputFormat','QQ/yyyy') datetime('02/2009','InputFormat','QQ/yyyy')], [30 30],-10);
hold on
b=area([datetime('03/2011','InputFormat','QQ/yyyy') datetime('01/2013','InputFormat','QQ/yyyy')], [30 30],-10);
hold on
gg=plot(qdates,yt,'Linewidth',1.5,'Linestyle','-.','Marker','+');
ylabel('quarter-over-quarter real GDP growth (%)')
ylim([-4 4])
grid on
yyaxis right
qq=plot(qdates,zt,'Linewidth',1.5);
xlim([datetime('01/1998','InputFormat','QQ/yyyy') datetime('04/2020','InputFormat','QQ/yyyy')])
ylabel('CISS')
xlabel('years')
xticks(datetime('01/1998','InputFormat','QQ/yyyy'):calquarters(8):datetime('04/2020','InputFormat','QQ/yyyy'))
set(a,'FaceColor',[255/255 250/255 205/255], 'EdgeColor', 'y')
set(b,'FaceColor',[255/255 250/255 205/255], 'EdgeColor', 'y')
ylim([-0.8 0.8])
%ylim([-5 3])
box on
grid on
set(gca,'layer','top')
legend([gg,qq,a],'q-o-q real GDP growth','CISS','CEPR recessions','Location','SouthWest')

set(gcf,'PaperUnits','inches');
set(gcf,'PaperSize',[6.5 5]);
set(gcf,'PaperPositionMode','manual');
set(gcf,'PaperPosition',[0 0 6.5 5]);

set(gcf,'renderer','painters');
eval(['print -dpdf pdf/Fig01']);

