
clear variables; clc;

addpath('../library/')

results_root = '../results';
model_name   = [{'benchmark'},{'onlyGDP'},{'ftp'},{'normal'}];

% probability bands
p = [5 16 50 68 95];

% retrieve results
model = cell(length(model_name),1);
for i=1:length(model_name)
    model{i} = load([results_root,'/models/',model_name{i},'/insample_stats.mat'], ...
                     'samples_mean','samples_variance','samples_skewness_coef','samples_kurtosis_coef','Dat');
end
model = [model{1:length(model_name)}];

samples_mean          = cat(3,model.samples_mean);
samples_variance      = cat(3,model.samples_variance);
samples_skewness_coef = cat(3,model.samples_skewness_coef);
samples_kurtosis_coef = cat(3,model.samples_kurtosis_coef);

% date
Dat = model(1).Dat;

% sample size
T = length(Dat);

% memory allocation
quan_expectation    = NaN(length(p),T,length(model_name));
quan_variance       = NaN(length(p),T,length(model_name));
quan_skewness_coeff = NaN(length(p),T,length(model_name));
quan_kurtosis_coeff = NaN(length(p),T,length(model_name));

for i=1:length(model_name)
    quan_expectation(:,:,i)    = prctile(samples_mean(:,:,i),p);
    quan_variance(:,:,i)       = prctile(samples_variance(:,:,i),p);
    quan_skewness_coeff(:,:,i) = prctile(samples_skewness_coef(:,:,i),p);
    quan_kurtosis_coeff(:,:,i) = prctile(samples_kurtosis_coef(:,:,i),p);
end

% figure
make_it_tight = true;                     % GAP        LOWER UPPER  LEFT RIGHT
subplot = @(m,n,p) subtightplot (m, n, p, [0.12 0.05], [0.1 0.04], [0.04 0.02]);
if ~make_it_tight,  clear subplot;  end

figure;
subplot(2,2,1)
a=quan_expectation(1,:,1);
b=quan_expectation(5,:,1);
c=quan_expectation(2,:,1);
d=quan_expectation(4,:,1);
x=Dat;
aa=area([datetime('01/2008','InputFormat','MM/yyyy') datetime('06/2009','InputFormat','MM/yyyy')], [30 30],-10);
hold on
bb=area([datetime('09/2011','InputFormat','MM/yyyy') datetime('01/2013','InputFormat','MM/yyyy')], [30 30],-10);
set(aa,'FaceColor',[255/255 250/255 205/255], 'EdgeColor', 'y')
set(bb,'FaceColor',[255/255 250/255 205/255], 'EdgeColor', 'y')
hold on
[az1,~]=jbfill(x,a,b,[0, 0.4470, 0.7410],[0, 0.4470, 0.7410],0,0.3);
hold on
[az2,~]=jbfill(x,c,d,[0, 0.4470, 0.7410],[0, 0.4470, 0.7410],0,0.6);
hold on
p1=plot(Dat,quan_expectation(3,:,1),'LineWidth',1.0,'Color','k');
hold on
p2=plot(Dat,quan_expectation(3,:,2),'LineWidth',1.0,'Color',[0.8500, 0.3250, 0.0980],'LineStyle','--');
hold on
p3=plot(Dat,quan_expectation(3,:,3),'LineWidth',1.0,'Color',[0.9290, 0.6940, 0.1250],'LineStyle','-.');
hold on
p4=plot(Dat,quan_expectation(3,:,4),'LineWidth',1.5,'Color',[0.4940, 0.1840, 0.5560],'LineStyle',':');
box on; grid on;
xlabel('years')
t=title('Panel A. Mean');
set(t, 'horizontalAlignment', 'left')
set(t, 'units', 'normalized')
h = get(t, 'position');
set(t, 'position', [0 1 0])
xticks(datetime('01/1998','InputFormat','MM/yyyy'):calquarters(8):datetime('12/2020','InputFormat','MM/yyyy'))
xtickangle(45)
ylim([-4 max([a,b,c,d])])
lgd=legend([p1,p2,p3,p4],'MS skew-normal with GDP + CISS','MS skew-normal with GDP','MS skew-normal','MS Gaussian','Location','SouthEast','NumColumns',1);%,'EdgeColor','none');
%
subplot(2,2,2)
a=quan_variance(1,:,1);
b=quan_variance(5,:,1);
c=quan_variance(2,:,1);
d=quan_variance(4,:,1);
x=Dat;
aa=area([datetime('01/2008','InputFormat','MM/yyyy') datetime('06/2009','InputFormat','MM/yyyy')], [30 30],-10);
hold on
bb=area([datetime('09/2011','InputFormat','MM/yyyy') datetime('01/2013','InputFormat','MM/yyyy')], [30 30],-10);
set(aa,'FaceColor',[255/255 250/255 205/255], 'EdgeColor', 'y')
set(bb,'FaceColor',[255/255 250/255 205/255], 'EdgeColor', 'y')
hold on
[az1,~]=jbfill(x,a,b,[0, 0.4470, 0.7410],[0, 0.4470, 0.7410],0,0.3);
hold on
[az2,~]=jbfill(x,c,d,[0, 0.4470, 0.7410],[0, 0.4470, 0.7410],0,0.6);
hold on
p1=plot(Dat,quan_variance(3,:,1),'LineWidth',1.0,'Color','k');
hold on
p2=plot(Dat,quan_variance(3,:,2),'LineWidth',1.0,'Color',[0.8500, 0.3250, 0.0980],'LineStyle','--');
hold on
p3=plot(Dat,quan_variance(3,:,3),'LineWidth',1.0,'Color',[0.9290, 0.6940, 0.1250],'LineStyle','-.');
hold on
p4=plot(Dat,quan_variance(3,:,4),'LineWidth',1.5,'Color',[0.4940, 0.1840, 0.5560],'LineStyle',':');
box on; grid on;
xlabel('years')
t=title('Panel B. Variance');
set(t, 'horizontalAlignment', 'left')
set(t, 'units', 'normalized')
h = get(t, 'position');
set(t, 'position', [0 1 0])
%lgd=legend([p1,az1,az2,p2,p3,p4],'GDP + CISS (median)','GDP + CISS (90% error bands)', 'GDP + CISS (68% error bands)','only GDP (median)','FTP (median)','MS Gaussian (median)','Location','NorthEast','NumColumns',2,'Position',[0.199517686778956 0.00468306916097486 0.642857129126787 0.11190475892453]);%,'EdgeColor','none');
set(lgd,'FontSize',8);
xticks(datetime('01/1998','InputFormat','MM/yyyy'):calquarters(8):datetime('12/2020','InputFormat','MM/yyyy'))
xtickangle(45)
ylim([min([a,b,c,d]) max([a,b,c,d])])
%
subplot(2,2,3)
a=quan_skewness_coeff(1,:,1);
b=quan_skewness_coeff(5,:,1);
c=quan_skewness_coeff(2,:,1);
d=quan_skewness_coeff(4,:,1);
x=Dat;
aa=area([datetime('01/2008','InputFormat','MM/yyyy') datetime('06/2009','InputFormat','MM/yyyy')], [30 30],-10);
hold on
bb=area([datetime('09/2011','InputFormat','MM/yyyy') datetime('01/2013','InputFormat','MM/yyyy')], [30 30],-10);
set(aa,'FaceColor',[255/255 250/255 205/255], 'EdgeColor', 'y')
set(bb,'FaceColor',[255/255 250/255 205/255], 'EdgeColor', 'y')
hold on
[az1,~]=jbfill(x,a,b,[0, 0.4470, 0.7410],[0, 0.4470, 0.7410],0,0.3);
hold on
[az2,~]=jbfill(x,c,d,[0, 0.4470, 0.7410],[0, 0.4470, 0.7410],0,0.6);
hold on
plot(Dat,quan_skewness_coeff(3,:,1),'LineWidth',1.0,'Color','k');
hold on
plot(Dat,quan_skewness_coeff(3,:,2),'LineWidth',1.0,'Color',[0.8500, 0.3250, 0.0980],'LineStyle','--');
hold on
plot(Dat,quan_skewness_coeff(3,:,3),'LineWidth',1.0,'Color',[0.9290, 0.6940, 0.1250],'LineStyle','-.');
hold on
plot(Dat,quan_skewness_coeff(3,:,4),'LineWidth',1.5,'Color',[0.4940, 0.1840, 0.5560],'LineStyle',':');
box on; grid on;
xlabel('years')
t=title('Panel C. Skewness coefficient');
set(t, 'horizontalAlignment', 'left')
set(t, 'units', 'normalized')
h = get(t, 'position');
set(t, 'position', [0 1 0])
yticks([-5 -2.5 0 2.5 5])
xticks(datetime('01/1998','InputFormat','MM/yyyy'):calquarters(8):datetime('12/2020','InputFormat','MM/yyyy'))
xtickangle(45)
ylim([min([a,b,c,d]) max([a,b,c,d])])
%
subplot(2,2,4)
a=quan_kurtosis_coeff(1,:,1);
b=quan_kurtosis_coeff(5,:,1);
c=quan_kurtosis_coeff(2,:,1);
d=quan_kurtosis_coeff(4,:,1);
x=Dat;
aa=area([datetime('01/2008','InputFormat','MM/yyyy') datetime('06/2009','InputFormat','MM/yyyy')], [300 300],-10);
hold on
bb=area([datetime('09/2011','InputFormat','MM/yyyy') datetime('01/2013','InputFormat','MM/yyyy')], [300 300],-10);
set(aa,'FaceColor',[255/255 250/255 205/255], 'EdgeColor', 'y')
set(bb,'FaceColor',[255/255 250/255 205/255], 'EdgeColor', 'y')
hold on
[az1,~]=jbfill(x,a,b,[0, 0.4470, 0.7410],[0, 0.4470, 0.7410],0,0.3);
hold on
[az2,~]=jbfill(x,c,d,[0, 0.4470, 0.7410],[0, 0.4470, 0.7410],0,0.6);
hold on
plot(Dat,quan_kurtosis_coeff(3,:,1),'LineWidth',1.0,'Color','k');
hold on
plot(Dat,quan_kurtosis_coeff(3,:,2),'LineWidth',1.0,'Color',[0.8500, 0.3250, 0.0980],'LineStyle','--');
hold on
plot(Dat,quan_kurtosis_coeff(3,:,3),'LineWidth',1.0,'Color',[0.9290, 0.6940, 0.1250],'LineStyle','-.');
hold on
plot(Dat,quan_kurtosis_coeff(3,:,4),'LineWidth',1.5,'Color',[0.4940, 0.1840, 0.5560],'LineStyle',':');
box on; grid on;
xlabel('years')
t=title('Panel D. Kurtosis coefficient');
set(t, 'horizontalAlignment', 'left')
set(t, 'units', 'normalized')
h = get(t, 'position');
set(t, 'position', [0 1 0])
xticks(datetime('01/1998','InputFormat','MM/yyyy'):calquarters(8):datetime('12/2020','InputFormat','MM/yyyy'))
xtickangle(45)
ylim([min([a,b,c,d]) max([a,b,c,d])])


set(gcf,'PaperUnits','inches');
set(gcf,'PaperSize',[7 7]);
set(gcf,'PaperPositionMode','manual');
set(gcf,'PaperPosition',[0 0 7 7]);

set(gcf,'renderer','painters');
eval('print -dpdf pdf/Fig04');

