
clear variables; close all; clc;

addpath('../library/Tatevik')
addpath('../library')

results_root = '../results';

% percentile
p = [5 16 50 84 95];

% h-step-ahead forecast
h = 1;                           % Forecast horizon (set to [] if h-step-ahead forecast not desired)
numdraw_h = 5e3;                 % Number of posterior parameter draws to consider

% Beginning of OOS Foreacasting
IntDat    = datetime('04/01/2010','InputFormat','MM/dd/yyyy');

% End of OOS FOrecasting
EndDat    = datetime('10/01/2019','InputFormat','MM/dd/yyyy');

% Time Series of OOS Estimation Date
DatRT     = IntDat:calquarters(1):EndDat;

% Time Series of OOS Date
Dat       = DatRT(1:end-h);

% Out-of-sample Results
oos_benchmark=struct;
oos_onlyGDP=struct;
oos_ftp=struct;
oos_gaussian=struct;

oos_benchmark.samples_score=nan(numdraw_h,length(Dat));
oos_onlyGDP.samples_score=nan(numdraw_h,length(Dat));
oos_ftp.samples_score=nan(numdraw_h,length(Dat));
oos_gaussian.samples_score=nan(numdraw_h,length(Dat));

oos_benchmark.samples_Pit=nan(numdraw_h,length(Dat));
oos_onlyGDP.samples_Pit=nan(numdraw_h,length(Dat));
oos_ftp.samples_Pit=nan(numdraw_h,length(Dat));
oos_gaussian.samples_Pit=nan(numdraw_h,length(Dat));

for i=1:length(Dat)
    
    % benchmark
    oos_benchmark_foreh = load([results_root,'/models/benchmark/real-time/outofsample/',datestr(DatRT(i)),'.mat'],'samples_score','samples_Pit');
    oos_benchmark.samples_score(:,i) = oos_benchmark_foreh.samples_score;
    oos_benchmark.samples_Pit(:,i) = oos_benchmark_foreh.samples_Pit;
    
    % only GDP
    oos_onlyGDP_foreh = load([results_root,'/models/onlyGDP/real-time/outofsample/',datestr(DatRT(i)),'.mat'],'samples_score','samples_Pit');
    oos_onlyGDP.samples_score(:,i) = oos_onlyGDP_foreh.samples_score;
    oos_onlyGDP.samples_Pit(:,i) = oos_onlyGDP_foreh.samples_Pit;

    % ftp
    oos_ftp_foreh = load([results_root,'/models/ftp/real-time/outofsample/',datestr(DatRT(i)),'.mat'],'samples_score','samples_Pit');
    oos_ftp.samples_score(:,i) = oos_ftp_foreh.samples_score;
    oos_ftp.samples_Pit(:,i) = oos_ftp_foreh.samples_Pit;

    % Gaussian
    oos_gaussian_foreh = load([results_root,'/models/normal/real-time/outofsample/',datestr(DatRT(i)),'.mat'],'samples_score','samples_Pit');
    oos_gaussian.samples_score(:,i) = oos_gaussian_foreh.samples_score;
    oos_gaussian.samples_Pit(:,i) = oos_gaussian_foreh.samples_Pit;
    
end

oos_benchmark_score = mean(oos_benchmark.samples_score);
oos_onlyGDP_score = mean(oos_onlyGDP.samples_score);
oos_ftp_score = mean(oos_ftp.samples_score);
oos_gaussian_score = mean(oos_ftp.samples_score);

oos_benchmark_Pit = mean(oos_benchmark.samples_Pit)';
oos_onlyGDP_Pit = mean(oos_onlyGDP.samples_Pit)';
oos_ftp_Pit = mean(oos_ftp.samples_Pit)';
oos_gaussian_Pit = mean(oos_gaussian.samples_Pit)';

% PITs
% The code below was modified from files provided by Barbara Rossi and
% Tatevik Sekhposyan implementing the specification tests for predictive
% densities described in Rossi and Sekhposyan (2017).
rvec = 0:0.001:1;
zbenchmark_ecdf = PITtest(oos_benchmark_Pit, rvec);
zonlyGDP_ecdf = PITtest(oos_onlyGDP_Pit, rvec);
zftp_ecdf = PITtest(oos_ftp_Pit, rvec);
zgaussian_ecdf = PITtest(oos_gaussian_Pit, rvec);
if h == 1
    % Use asymptotic 5% critical value from Rossi and Sekhposyan (2017): 1.34
    kappa        = 1.34;
    kappaGDPonly = 1.34;
end

make_it_tight = true;                     % GAP        LOWER UPPER  LEFT RIGHT
subplot = @(m,n,p) subtightplot (m, n, p, [0.12 0.08], [0.16 0.05], [0.08 0.01]);
if ~make_it_tight,  clear subplot;  end


figure;
subplot(1,1,1) % Plot PIT
plot(rvec,zbenchmark_ecdf,'LineWidth',1.5)
hold on
plot(rvec,zonlyGDP_ecdf,'LineWidth',1.5,'LineStyle','--')
hold on
plot(rvec,zftp_ecdf,'LineWidth',1.5,'LineStyle','-.')
hold on
plot(rvec,zgaussian_ecdf,'color',[0.4940, 0.1840, 0.5560],'LineWidth',1.5,'LineStyle',':');
hold on
P = sum(isnan(oos_benchmark_Pit) == 0);
plot(rvec, [rvec', rvec' - (kappa / sqrt(P)), rvec' + (kappa / sqrt(P))], '-k','LineWidth',0.5);
hold off
xlim([0, 1])
ylim([0, 1])
xlabel('\tau')
ylabel('Empirical CDF')
grid on
legend('MS skew-normal with GDP + CISS','MS skew-normal with GDP','MS skew-normal','MS Gaussian','Theoretical and 5% Critical Values','Location','SouthEast')

set(gcf,'PaperUnits','inches');
set(gcf,'PaperSize',[6.5 2.5]);
set(gcf,'PaperPositionMode','manual');
set(gcf,'PaperPosition',[0 0 6.5 2.5]);

set(gcf,'renderer','painters');
eval('print -dpdf pdf/Fig07');
