
clear variables; close all; clc;

addpath '../library/'
addpath '../library/skn-library/'

results_root = '../results';

deltaYY = 2^9;                   % the number of mesh points 
Y_min   = -15;
Y_max   = 15;
YY      = linspace(Y_min,Y_max,deltaYY);

% date around overeign debt crisis
Dat     = [{'01-Jul-2011'},{'01-Oct-2011'},{'01-Jan-2012'},{'01-Apr-2012'},{'01-Jul-2012'},{'01-Oct-2012'}];
DatName = [{'2011-Q3'},{'2011-Q4'},{'2012-Q1'},{'2012-Q2'},{'2012Q3'},{'2012Q4'}];

n=length(Dat);
m=length(YY);

quan_benchmark_pst = NaN(n,m);
quan_onlyGDP_pst   = NaN(n,m);
quan_ftp_pst       = NaN(n,m);

make_it_tight = true;                     % GAP        LOWER UPPER  LEFT RIGHT
subplot = @(m,n,p) subtightplot (m, n, p, [0.11 0.1], [0.08 0.05], [0.06 0.01]);
if ~make_it_tight,  clear subplot;  end

figure;
for i=1:n
    
    % Gibbs output
    benchmark = load([results_root,'/models/benchmark/real-time/outofsample/',Dat{i},'.mat'],'samples_pst','ytRealized');
    onlyGDP   = load([results_root,'/models/onlyGDP/real-time/outofsample/',Dat{i},'.mat'],'samples_pst');
    ftp       = load([results_root,'/models/ftp/real-time/outofsample/',Dat{i},'.mat'],'samples_pst');
    gaussian  = load([results_root,'/models/normal/real-time/outofsample/',Dat{i},'.mat'],'samples_pst');
    
    % memory allocation
    quan_benchmark_pst = median(benchmark.samples_pst);
    quan_onlyGDP_pst   = median(onlyGDP.samples_pst);
    quan_ftp_pst       = median(ftp.samples_pst);
    quan_gaussian_pst  = median(gaussian.samples_pst);
   
    % subplots
    subplot(3,2,i)
    plot(YY,quan_benchmark_pst,'color',[0, 0.4470, 0.7410],'LineWidth',2)
    hold on
    plot(YY,quan_onlyGDP_pst,'color',[0.8500, 0.3250, 0.0980],'LineWidth',2,'Linestyle','--')
    hold on
    plot(YY,quan_ftp_pst,'color',[0.9290, 0.6940, 0.1250],'LineWidth',2,'Linestyle','-.')
    hold on
    plot(YY,quan_gaussian_pst,'LineWidth',2,'color',[0.4940, 0.1840, 0.5560],'LineStyle',':');
    hold on
    xline(benchmark.ytRealized,'LineWidth',1.0);
    if i==1
        xlim([-6 2])
    else
        xlim([-2 2])
    end
    t=title(DatName{i},'FontSize',10);
    set(t, 'horizontalAlignment', 'left')
    set(t, 'units', 'normalized')
    set(t, 'position', [0 1 0])
    xlabel('Real GDP growth rates')
    ylabel('density function')
    grid on; box on;
    
    if i==1
        legend('MS skew-normal with GDP + CISS','MS skew-normal with GDP','MS skew-normal','MS Gaussian','Realized data','Location','NorthWest')
    end
    
end

set(gcf,'PaperUnits','inches');
set(gcf,'PaperSize',[7 5]);
set(gcf,'PaperPositionMode','manual');
set(gcf,'PaperPosition',[0 0 7 5]);
    
set(gcf,'renderer','painters');
print -dpdf pdf/Fig08
