function M = getModel(filedate,name_file)

% Real-time estimation [until t='filedate']
filename=['results/models/',name_file,'/real-time/mode/',datestr(filedate),'.mat'];
load(filename,'Postmode','pr_st0','options_','Dat');

param = Postmode;

% Load Data (Estimation Sample)
% --
M.yt               = options_.data;
M.t                = size(M.yt,1);

% Load Data (Full Sample)
M.ytTab           = options_.ytTab;
M.ztTab           = options_.ztTab;

% Assign Values to Parameters
% --
M.Postmode = Postmode;
M.Dat      = Dat;

M.params.location  = [param(1); param(1); param(2); param(2); param(1); param(1); param(2); param(2)]; 
M.params.invscale2 = [param(3); param(4); param(3); param(4); param(3); param(4); param(3); param(4)];
M.params.scale     = sqrt(1./M.params.invscale2);
M.params.shape     = [param(5); param(5); param(5); param(5); param(6); param(6); param(6); param(6)];
M.params.adjshape  = M.params.shape./(sqrt(1+M.params.shape.^2));

M.regimes = [1,1,1,1,0,0,0,0
             1,1,0,0,1,1,0,0
             1,0,1,0,1,0,1,0];
         
M.nprocess = 3;

M.params.phi       = param(7);

M.params.a1        = [param(8); param(14);param(20)];
M.params.a2        = [param(9); param(15);param(21)];
M.params.b1        = [param(10) param(16) param(22)   % b11
                      param(11) param(17) param(23)]; % b12
M.params.b2        = [param(12) param(18) param(24)   % b21
                      param(13) param(19) param(25)]; % b22

Q                  = tran_p2q(M.params.a1,M.params.a2,M.params.b1,M.params.b2,zeros(1,2));
M.s                = mcdraw_f2_most_likely(Q,pr_st0);
M.fp               = pr_st0;
M.nreg             = size(pr_st0,2);

% Define Prior (Same as the one used in the optimization routine)
% --
M.prior.location.mu  = options_.pmean(1:2);
M.prior.location.sig = options_.pstdd(1:2).^2;
M.prior.invscale2.a  = options_.pmean(3:4);
M.prior.invscale2.b  = options_.pstdd(3:4);
M.prior.shape.mu     = options_.pmean(5:6);
M.prior.shape.sig    = options_.pstdd(5:6);
M.prior.phi.mu       = options_.pmean(7);
M.prior.phi.sig      = options_.pstdd(7).^2;
M.prior.a1.mu        = options_.pmean([8,14,20]);
M.prior.a1.sig       = options_.pstdd([8,14,20]);
M.prior.a2.mu        = options_.pmean([9,15,21]);
M.prior.a2.sig       = options_.pstdd([9,15,21]);
M.prior.b1.mu        = [options_.pmean([10,16,22]),options_.pmean([11,17,23])];
M.prior.b1.sig       = [options_.pstdd([10,16,22]),options_.pstdd([11,17,23])];
M.prior.b2.mu        = [options_.pmean([12,18,24]),options_.pmean([13,19,25])];
M.prior.b2.sig       = [options_.pstdd([12,18,24]),options_.pstdd([13,19,25])];

M.prior.transition_matrix.mu  = [M.prior.a1.mu,M.prior.a2.mu,M.prior.b1.mu(:,1),M.prior.b1.mu(:,2),M.prior.b2.mu(:,1),M.prior.b2.mu(:,2)]';
M.prior.transition_matrix.sig = NaN(6,6,3);
for i=1:size(M.regimes,1)
    M.prior.transition_matrix.sig(:,:,i) = diag([M.prior.a1.sig(i),M.prior.a2.sig(i),M.prior.b1.sig(i,1),M.prior.b1.sig(i,2),M.prior.b2.sig(i,1),M.prior.b2.sig(i,2)]).^2;
end

M.DatRT = filedate;
M.name_file = name_file;
