function [lik, pr_st0, pr_stl0, Qstore, lik_mat] = ms3p_tvtp_lik(param,y)

location  = [param(1); param(1); param(2); param(2); param(1); param(1); param(2); param(2)];
invscale2 = [param(3); param(4); param(3); param(4); param(3); param(4); param(3); param(4)]; 
scale     = sqrt(1./invscale2);
shape     = [param(5); param(5); param(5); param(5); param(6); param(6); param(6); param(6)];

phi1     = param(7);

a1       = [param(8); param(14);param(20)];
a2       = [param(9); param(15);param(21)];
b1       = [param(10) param(16) param(22)
            param(11) param(17) param(23)];       
b2       = [param(12) param(18) param(24)
            param(13) param(19) param(25)];                        

t = size(y,1);

nstates = length(location);%size(Q,1);

% Initializing Markov-switching framework
%--------------------------------------------------------------
%Steady-state probabilities PR[S_t=0] and PR[S_t=1]
Prob = 1/nstates*ones(nstates,1);
%Prob    = vecr(Prob_ss(:,ones(1,nstates))); % A 4x1 matrix
%Prob_ss = 1/nstates*ones(nstates,1);
%Prob    = vecr(Prob_ss(:,ones(1,nstates))); % A 4x1 matrix

pr_st0  = zeros(t,nstates); % save all Pr[S_t=0|Y_{t}]
pr_stl0 = zeros(t,nstates); % save all Pr[S_t=0|Y_{t-1}]

Qstore = NaN(nstates,nstates,t);


% The sample log-likelihood function
%--------------------------------------------------------------
lik_mat = zeros(t,1);
lcond   = zeros(nstates,1);

for k=1:t

    %
    pr_11 = normcdf(-a1(1)-y(k,2:3)*b1(:,1)); 
    pr_22 = 1-normcdf(-a1(1)-a2(1)-y(k,2:3)*b2(:,1));
    
    Q1 = [   pr_11   1-pr_22 
          1-pr_11     pr_22];

    pr_11 = normcdf(-a1(2)-y(k,2:3)*b1(:,2)); 
    pr_22 = 1-normcdf(-a1(2)-a2(2)-y(k,2:3)*b2(:,2));
    
    Q2 = [   pr_11   1-pr_22 
          1-pr_11     pr_22];

    pr_11 = normcdf(-a1(3)-y(k,2:3)*b1(:,3)); 
    pr_22 = 1-normcdf(-a1(3)-a2(3)-y(k,2:3)*b2(:,3));
    
    Q3 = [   pr_11   1-pr_22 
          1-pr_11     pr_22];
      
    Q = kron(kron(Q1,Q2),Q3);
    
    Qstore(:,:,k) = Q;

    Prob_j = Q*Prob;  % A 4x1 vector  
    %Prob_j = Q(:).*Prob; % A 4x1 vector  
    
    for j=1:nstates
        lcond(j,:) = log(2) - 0.5*log(2*pi) - log(scale(j)) - ((y(k,1)-location(j)-phi1*y(k,2)).^2)./(2*scale(j).^2) + log(normcdf(shape(j).*(y(k,1)-location(j)-phi1*y(k,2))./scale(j)));
        
        %xt = (y(k,1)-location(j)-phi*(y(k,2)))/scale(j);
        %lcond(j,:) = log(2) - log(scale(j)) + log(tpdf(xt,nu(j))) + log(tcdf(shape(j)*xt*sqrt((nu(j)+1)/(nu(j)+xt^2)),nu(j)+1));
    end

	%vec_lcond = lcond(:,ones(1,nstates));

	%conditional densities, weight being Pr[S_{t}=j,S_{t-1}=i|Y_{t-1}]
	densj = lcond + log(Prob_j);
	%densj = vec_lcond(:) + log(Prob_j);

	%log of Weighted average of conditional densities Pr[Y_t|Y_{t-1}] --
	maxdensj = max(densj);
	dens = log(sum(exp(densj - maxdensj))) + maxdensj;

	%log likelihood for each date
	lik_mat(k,1) = dens;

	%Update the probability terms Pr[S_t,S_{t-1}|Y_t] -----------
	Prob = exp(densj - dens);
    %JointProb = exp(densj - dens);

	%Update the probability terms Pr[S_t|Y_t] -------------------
	%Pr = sum(reshape(JointProb,nstates,nstates),2);

	%build the probability terms Prob for the next period
	%Prob = vecr(Pr(:,ones(1,nstates)));

	%get the probability terms Pr[S_t=0|Y_{t-1}] for Kim filter
	%tmp = sum(reshape(Prob_j,nstates,nstates),2);

	pr_st0(k,:)  = Prob';  % Pr[S_t=0|Y_t]
	pr_stl0(k,:) = Prob_j'; % Pr[S_t=0|Y_{t-1}]
	%pr_st0(k,:)  = Pr';  % Pr[S_t=0|Y_t]
	%pr_stl0(k,:) = tmp'; % Pr[S_t=0|Y_{t-1}]                                                                                            
end

lik = sum(lik_mat(:,1));
