function [expectation,variance,skewness,skewness_coeff,kurtosis,kurtosis_coeff] = ms_skn_moments(pr, location, scale, shape)
%
% Compute first four moments - mean, variance, skewness, and kurtosis - of
% a Markov-swiching model with location, scale and shape parameters varying
% over time. 
%
% by Stephane LHUISSIER, 2020

t = size(pr,1);
r = size(location,2);

mu0 = 1*ones(1,r);
mu1 = (shape*sqrt(2))./(sqrt(1+shape.^2)*sqrt(pi));
mu2 = 1*ones(1,r);
mu3 = ((shape*sqrt(2)).*(3+2*shape.^2))./(sqrt(pi)*((1+shape.^2)).^(3/2));
mu4 = 3*ones(1,r);
mu  = [mu0;mu1;mu2;mu3;mu4];

% 1st moment
% =================
b   = sqrt(2/pi);
del = shape./sqrt(1+shape.^2);
muz = b*del;

expectation = sum(pr.*(location+scale.*muz),2);


% 2nd moment
% =================
n = 2;
conditional_variance = NaN(t,r);
for k = 1:t
    for i = 1:r
        tmp = 0;
        for j = 0:n
            tmp = tmp + nchoosek(n,j)*scale(i)^j*mu(j+1,i)*(location(i)-expectation(k))^(n-j);
        end
        conditional_variance(k,i) = tmp;
    end
end

variance = sum(pr.*conditional_variance,2);


% 3rd moment
% =================
n = 3;
conditional_skewness       = NaN(t,r);
for k = 1:t
    for i = 1:r
        tmp = 0;
        for j = 0:n
            tmp = tmp + nchoosek(n,j)*scale(i)^j*mu(j+1,i)*((location(i)-expectation(k))^(n-j));
        end
        conditional_skewness(k,i) = tmp;
    end
end

skewness       = sum(pr.*conditional_skewness,2);
skewness_coeff = skewness./(variance.^(3/2));


% 4th moment
% =================
n = 4;
conditional_kurtosis       = NaN(t,r);
for k = 1:t
    for i = 1:r
        tmp = 0;
        for j = 0:n
            tmp = tmp + nchoosek(n,j)*scale(i)^j*mu(j+1,i)*(location(i)-expectation(k))^(n-j);
        end
        conditional_kurtosis(k,i)       = tmp;
    end
end

kurtosis       = sum(pr.*conditional_kurtosis,2);
kurtosis_coeff = (kurtosis-3*variance.^2)./(variance.^2);

