%
% Code to replicate Lhuissier (2022): "Financial Conditions and 
% Macroeconomic Downside Risks in the Euro Area", European Economic Review
%   
% --> Gibbs-Sampling Procedure in Real Time (iteration procedure)
%
%
% Stephane Lhuissier, August 2021

% -------------------------------------------------------------------------
% Housekeeping
% -------------------------------------------------------------------------
clear variables; clc;

addpath 'library/'

% -------------------------------------------------------------------------
% Options and Data
% -------------------------------------------------------------------------

% Model Specification
name_file = 'benchmark';

% Number of workers (Parallel Gibbs Sampler)
nworkers = 16;

% Options for Gibbs sampler
rng(123);

Gibbs.n       = 55000;
Gibbs.nburn   = 5000;
Gibbs.nuse    = 10;

% Beginning of Real-Time
IntDat    = datetime('04/01/2010','InputFormat','MM/dd/yyyy');
% End of Estimation
EndDat    = datetime('10/01/2019','InputFormat','MM/dd/yyyy');
% Time Series of Estimation Date
DatRT     = IntDat:calquarters(1):EndDat;
% Number of estimation sequence
n         = length(DatRT);

% -------------------------------------------------------------------------
% Run Gibbs Sampler
% -------------------------------------------------------------------------

% Memory allocation
filedate = cell(n,1);
M        = cell(n,1);
Postdraw = cell(n,1);
Pr       = cell(n,1);

fprintf('Gibbs sampler starts here...\n');

tic
parfor (idx=1:n,nworkers)
    
    % Get vintage date
    % --
    filedate{idx}=DatRT(idx);
    
    % Model structure
    % --
    M{idx} = getModel(filedate{idx},name_file);
    
    % Running Gibbs sampler
    % --
    [Postdraw{idx}, Pr{idx}] = GibbsSamplerMSskew(M{idx},Gibbs);
    
end
fprintf('\nElapsed time: %s.\n',secs2hms(toc))
