clear variables; clc;

model_name    = 'loose050';

load(['../results/models/',model_name,'/posterior_mode.mat']);
load(['../results/models/',model_name,'/gibbs_draws.mat']);

Postdraw = [locationgbs(:,[1,3]),invscale2gbs(:,[1,2]),shapegbs(:,[1,5]), ...
            a1gbs(:,1),a2gbs(:,1),b11gbs(:,1),b12gbs(:,1),b21gbs(:,1),b22gbs(:,1), ...
            a1gbs(:,2),a2gbs(:,2),b11gbs(:,2),b12gbs(:,2),b21gbs(:,2),b22gbs(:,2), ...
            a1gbs(:,3),a2gbs(:,3),b11gbs(:,3),b12gbs(:,3),b21gbs(:,3),b22gbs(:,3)];
        
Postdraw_med   = median(Postdraw,1)';
Postdraw_mea   = mean(Postdraw,1)';
Postdraw_lim68 = hpdint(Postdraw,0.68,0)';
Postdraw_lim90 = hpdint(Postdraw,0.90,0)';

PostMatrix = [Postdraw_mea Postdraw_med Postdraw_lim68 Postdraw_lim90];

pmean   = options_.pmean(~options_.mask);
pstdd   = options_.pstdd(~options_.mask);

% Display Table in lateX format
fprintf('\n')
fprintf('\\begin{table}\n')
fprintf('\\begin{threeparttable}\n')
fprintf('\\center\n')
fprintf('{\\scriptsize\n')
fprintf('\\label{tab_prior_posterior}\n')
fprintf('\\caption{Prior and Posterior Distributions.}\n')
fprintf('\\begin{tabular}{lcrrrrrrrrr}\n')
fprintf(' \\hline\n ')
fprintf(' \\hline\n')
fprintf(' &  \\multicolumn{3}{c}{Prior} & & \\multicolumn{6}{c}{Posterior} \\\\\n')
fprintf(' \\cline{2-4}\n')
fprintf(' \\cline{6-11}\n')
fprintf(' Coefficient & Density & para(1) & para(2) & & Mean & Median & [16; & 84] & [5; & 95] \\\\\n')
fprintf(' \\hline\n')
fprintf('\\multicolumn{8}{l}{\\textbf{Skew-normal parameters}} \\\\\n ')  
fprintf(' $\\mu(s^\\text{location}=1)$ & N & $%.2f$ & $%.2f$ & & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ \\\\\n', ...
          pmean(1), pstdd(1), PostMatrix(1,1), PostMatrix(1,2), PostMatrix(1,3), PostMatrix(1,4), PostMatrix(1,5), PostMatrix(1,6))
fprintf(' $\\mu(s^\\text{location}=2)$ &  N & $%.2f$ & $%.2f$ & & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ \\\\\n', ...
          pmean(2), pstdd(2), PostMatrix(2,1), PostMatrix(2,2), PostMatrix(2,3), PostMatrix(2,4), PostMatrix(2,5), PostMatrix(2,6))
fprintf(' $1/\\sigma^2(s^\\text{scale}=1)$ & G & $%.2f$ & $%.2f$ & & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$  \\\\\n', ...
          pmean(3), pstdd(3), PostMatrix(3,1), PostMatrix(3,2), PostMatrix(3,3), PostMatrix(3,4), PostMatrix(3,5), PostMatrix(3,6))
fprintf(' $1/\\sigma^2(s^\\text{scale}=2)$ & G & $%.2f$ & $%.2f$ & & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ \\\\\n', ...
          pmean(4), pstdd(4), PostMatrix(4,1), PostMatrix(4,2), PostMatrix(4,3), PostMatrix(4,4), PostMatrix(4,5), PostMatrix(4,6))
fprintf(' $\\alpha(s^\\text{shape}=1)$ &  N & $%.2f$ & $%.2f$ & & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ \\\\\n', ...
          pmean(5), pstdd(5), PostMatrix(5,1), PostMatrix(5,2), PostMatrix(5,3), PostMatrix(5,4), PostMatrix(5,5), PostMatrix(5,6))
fprintf(' $\\alpha(s^\\text{shape}=2)$ &  N & $%.2f$ & $%.2f$ & & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ \\\\\n', ...
          pmean(6), pstdd(6), PostMatrix(6,1), PostMatrix(6,2), PostMatrix(6,3), PostMatrix(6,4), PostMatrix(6,5), PostMatrix(6,6)) 
fprintf(' & &  &  &  & &  & &  &   & \\\\\n') 
fprintf('\\multicolumn{8}{l}{\\textbf{Transition probability parameters, $s^\\text{location}$}} \\\\\n ')    
fprintf(' $\\gamma_{0}^\\text{location}$ &  N & $%.2f$ & $%.2f$ & & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ \\\\\n', ...
          pmean(13), pstdd(13), PostMatrix(13,1), PostMatrix(13,2), PostMatrix(13,3), PostMatrix(13,4), PostMatrix(13,5), PostMatrix(13,6))
fprintf(' $\\gamma_{1}^\\text{location}$ &  N & $%.2f$ & $%.2f$ & & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ \\\\\n', ...
          pmean(14), pstdd(14), PostMatrix(14,1), PostMatrix(14,2), PostMatrix(14,3), PostMatrix(14,4), PostMatrix(14,5), PostMatrix(14,6))      
fprintf(' $\\gamma_{\\text{gdp},1}^\\text{location}$ &  N & $%.2f$ & $%.2f$ & & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ \\\\\n', ...
          pmean(15), pstdd(15), PostMatrix(15,1), PostMatrix(15,2), PostMatrix(15,3), PostMatrix(15,4), PostMatrix(15,5), PostMatrix(15,6))   
fprintf(' $\\gamma_{\\text{ciss},1}^\\text{location}$ &  N & $%.2f$ & $%.2f$ & & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ \\\\\n', ...
          pmean(16), pstdd(16), PostMatrix(16,1), PostMatrix(16,2), PostMatrix(16,3), PostMatrix(16,4), PostMatrix(16,5), PostMatrix(16,6))     
fprintf(' $\\gamma_{\\text{gdp},2}^\\text{location}$ &  N & $%.2f$ & $%.2f$ & & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ \\\\\n', ...
          pmean(17), pstdd(17), PostMatrix(17,1), PostMatrix(17,2), PostMatrix(17,3), PostMatrix(17,4), PostMatrix(17,5), PostMatrix(17,6))
fprintf(' $\\gamma_{\\text{ciss},2}^\\text{location}$  & N & $%.2f$ & $%.2f$ & & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ \\\\\n', ...
          pmean(18), pstdd(18), PostMatrix(18,1), PostMatrix(18,2), PostMatrix(18,3), PostMatrix(18,4), PostMatrix(18,5), PostMatrix(18,6))  
fprintf(' & &  &  &  & &  & &  &   & \\\\\n') 
fprintf('\\multicolumn{8}{l}{\\textbf{Transition probability parameters, $s^\\text{scale}$}} \\\\\n ')    
fprintf(' $\\gamma_{0}^\\text{scale}$ &  N & $%.2f$ & $%.2f$ & & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ \\\\\n', ...
          pmean(19), pstdd(19), PostMatrix(19,1), PostMatrix(19,2), PostMatrix(19,3), PostMatrix(19,4), PostMatrix(19,5), PostMatrix(19,6))
fprintf(' $\\gamma_{1}^\\text{scale}$ &  N & $%.2f$ & $%.2f$ & & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ \\\\\n', ...
          pmean(20), pstdd(20), PostMatrix(20,1), PostMatrix(20,2), PostMatrix(20,3), PostMatrix(20,4), PostMatrix(20,5), PostMatrix(20,6))      
fprintf(' $\\gamma_{\\text{gdp},1}^\\text{scale}$ &  N & $%.2f$ & $%.2f$ & & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ \\\\\n', ...
          pmean(21), pstdd(21), PostMatrix(21,1), PostMatrix(21,2), PostMatrix(21,3), PostMatrix(21,4), PostMatrix(21,5), PostMatrix(21,6))   
fprintf(' $\\gamma_{\\text{ciss},1}^\\text{scale}$ &  N & $%.2f$ & $%.2f$ & & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ \\\\\n', ...
          pmean(22), pstdd(22), PostMatrix(22,1), PostMatrix(22,2), PostMatrix(22,3), PostMatrix(22,4), PostMatrix(22,5), PostMatrix(22,6))     
fprintf(' $\\gamma_{\\text{gdp},2}^\\text{scale}$ &  N & $%.2f$ & $%.2f$ & & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ \\\\\n', ...
          pmean(23), pstdd(23), PostMatrix(23,1), PostMatrix(23,2), PostMatrix(23,3), PostMatrix(23,4), PostMatrix(23,5), PostMatrix(23,6))
fprintf(' $\\gamma_{\\text{ciss},2}^\\text{scale}$  & N & $%.2f$ & $%.2f$ & & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ \\\\\n', ...
          pmean(24), pstdd(24), PostMatrix(24,1), PostMatrix(24,2), PostMatrix(24,3), PostMatrix(24,4), PostMatrix(24,5), PostMatrix(24,6)) 
fprintf(' & &  &  &  & &  & &  &   & \\\\\n') 
fprintf('\\multicolumn{8}{l}{\\textbf{Transition probability parameters, $s^\\text{shape}$}} \\\\\n ')    
fprintf(' $\\gamma_{0}^\\text{shape}$ &  N & $%.2f$ & $%.2f$ & & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ \\\\\n', ...
          pmean(7), pstdd(7), PostMatrix(7,1), PostMatrix(7,2), PostMatrix(7,3), PostMatrix(7,4), PostMatrix(7,5), PostMatrix(7,6))
fprintf(' $\\gamma_{1}^\\text{shape}$ &  N & $%.2f$ & $%.2f$ & & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ \\\\\n', ...
          pmean(8), pstdd(8), PostMatrix(8,1), PostMatrix(8,2), PostMatrix(8,3), PostMatrix(8,4), PostMatrix(8,5), PostMatrix(8,6))      
fprintf(' $\\gamma_{\\text{gdp},1}^\\text{shape}$ &  N & $%.2f$ & $%.2f$ & & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ \\\\\n', ...
          pmean(9), pstdd(9), PostMatrix(9,1), PostMatrix(9,2), PostMatrix(9,3), PostMatrix(9,4), PostMatrix(9,5), PostMatrix(9,6))   
fprintf(' $\\gamma_{\\text{ciss},1}^\\text{shape}$ &  N & $%.2f$ & $%.2f$ & & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ \\\\\n', ...
          pmean(10), pstdd(10), PostMatrix(10,1), PostMatrix(10,2), PostMatrix(10,3), PostMatrix(10,4), PostMatrix(10,5), PostMatrix(10,6))     
fprintf(' $\\gamma_{\\text{gdp},2}^\\text{shape}$ &  N & $%.2f$ & $%.2f$ & & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ \\\\\n', ...
          pmean(11), pstdd(11), PostMatrix(11,1), PostMatrix(11,2), PostMatrix(11,3), PostMatrix(11,4), PostMatrix(11,5), PostMatrix(11,6))
fprintf(' $\\gamma_{\\text{ciss},2}^\\text{shape}$  & N & $%.2f$ & $%.2f$ & & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ & $%.4f$ \\\\\n', ...
          pmean(12), pstdd(12), PostMatrix(12,1), PostMatrix(12,2), PostMatrix(12,3), PostMatrix(12,4), PostMatrix(12,5), PostMatrix(12,6))
fprintf(' \\hline\n')
fprintf('\\end{tabular}\n')
fprintf('\\begin{tablenotes}[para,flushleft]\n')
fprintf('\\small\n')
fprintf('\\textit{Note:} N stands for Normal, and G for Gamma distributions. The $16$ percent and $84$ percent demarcate the bounds of the $68$ percent probability interval, while the $5$ percent and $95$ percent demarcate the bounds of the $90$ percent probability interval. Para(1) and Para(2) correspond to the means and standard deviations for Normal Distributions, and to the hyperparameters for Gamma Distributions.\n')
fprintf('\\end{tablenotes}\n')
fprintf('}\n')
fprintf('\\end{threeparttable}\n')
fprintf('\\end{table}\n')
