
clear variables; close all; clc;

addpath('../library/')

results_root = '../results';

% In-sample Results
is_benchmark  = load([results_root,'/models/benchmark/insample_stats.mat'],'samples_rmse','samples_score','samples_IC','samples_TLF','samples_GZF','samples_ALS');
is_onlyGDP    = load([results_root,'/models/onlyGDP/insample_stats.mat'],'samples_rmse','samples_score','samples_IC','samples_TLF','samples_GZF','samples_ALS');
is_ftp        = load([results_root,'/models/ftp/insample_stats.mat'],'samples_rmse','samples_score','samples_IC','samples_TLF','samples_GZF','samples_ALS');
is_gaussian   = load([results_root,'/models/normal/insample_stats.mat'],'samples_rmse','samples_score','samples_IC','samples_TLF','samples_GZF','samples_ALS');

is_benchmark_rmse   = sqrt(is_benchmark.samples_rmse);
is_benchmark_lscore = mean(log(is_benchmark.samples_score))';
is_benchmark_IC     = mean(is_benchmark.samples_IC)';
is_benchmark_TLF    = mean(is_benchmark.samples_TLF)';
is_benchmark_GZF    = mean(is_benchmark.samples_GZF)';

is_onlyGDP_rmse     = sqrt(is_onlyGDP.samples_rmse);
is_onlyGDP_lscore   = mean(log(is_onlyGDP.samples_score))';
is_onlyGDP_IC      = mean(is_onlyGDP.samples_IC)';
is_onlyGDP_TLF      = mean(is_onlyGDP.samples_TLF)';
is_onlyGDP_GZF      = mean(is_onlyGDP.samples_GZF)';

is_ftp_rmse         = sqrt(is_ftp.samples_rmse);
is_ftp_lscore       = mean(log(is_ftp.samples_score))';
is_ftp_IC           = mean(is_ftp.samples_IC)';
is_ftp_TLF          = mean(is_ftp.samples_TLF)';
is_ftp_GZF          = mean(is_ftp.samples_GZF)';

is_gaussian_rmse         = sqrt(is_gaussian.samples_rmse);
is_gaussian_lscore       = mean(log(is_gaussian.samples_score))';
is_gaussian_IC           = mean(is_gaussian.samples_IC)';
is_gaussian_TLF          = mean(is_gaussian.samples_TLF)';
is_gaussian_GZF          = mean(is_gaussian.samples_GZF)';

T = size(is_onlyGDP_rmse,1);

% Diebold and Mariano (1995) - West (1996) t-tests
[is_DMW_benchmark_rmse,is_GWp_benchmark_rmse,is_pvalue_benchmark_rmse]    = dmwtest(is_benchmark_rmse,is_gaussian_rmse,0.05);
[is_DMW_benchmark_score,is_GWp_benchmark_score,is_pvalue_benchmark_score] = dmwtest(is_benchmark_lscore,is_gaussian_lscore,0.05);
[is_DMW_benchmark_IC,is_GWp_benchmark_IC,is_pvalue_benchmark_IC]          = dmwtest(is_benchmark_IC,ones(T,1)*0.05,0.05);
[is_DMW_benchmark_TLF,is_GWp_benchmark_TLF,is_pvalue_benchmark_TLF]       = dmwtest(is_benchmark_TLF,is_gaussian_TLF,0.05);
[is_DMW_benchmark_GZF,is_GWp_benchmark_GZF,is_pvalue_benchmark_GZF]       = dmwtest(is_benchmark_GZF,is_gaussian_GZF,0.05);

[is_DMW_onlyGDP_rmse,is_GWp_onlyGDP_rmse,is_pvalue_onlyGDP_rmse]      = dmwtest(is_onlyGDP_rmse,is_gaussian_rmse,0.05);
[is_DMW_onlyGDP_score,is_GWp_onlyGDP_score,is_pvalue_onlyGDP_score]   = dmwtest(is_onlyGDP_lscore,is_gaussian_lscore,0.05);
[is_DMW_onlyGDP_IC,is_GWp_onlyGDP_IC,is_pvalue_onlyGDP_IC]            = dmwtest(is_onlyGDP_IC,ones(T,1)*0.05,0.05);
[is_DMW_onlyGDP_TLF,is_GWp_onlyGDP_TLF,is_pvalue_onlyGDP_TLF]         = dmwtest(is_onlyGDP_TLF,is_gaussian_TLF,0.05);
[is_DMW_onlyGDP_GZF,is_GWp_onlyGDP_GZF,is_pvalue_onlyGDP_GZF]         = dmwtest(is_onlyGDP_GZF,is_gaussian_GZF,0.05);

[is_DMW_ftp_rmse,is_GWp_ftp_rmse,is_pvalue_ftp_rmse]      = dmwtest(is_ftp_rmse,is_gaussian_rmse,0.05);
[is_DMW_ftp_score,is_GWp_ftp_score,is_pvalue_ftp_score]   = dmwtest(is_ftp_lscore,is_gaussian_lscore,0.05);
[is_DMW_ftp_IC,is_GWp_ftp_IC,is_pvalue_ftp_IC]            = dmwtest(is_ftp_IC,ones(T,1)*0.05,0.05);
[is_DMW_ftp_TLF,is_GWp_ftp_TLF,is_pvalue_ftp_TLF]         = dmwtest(is_ftp_TLF,is_gaussian_TLF,0.05);
[is_DMW_ftp_GZF,is_GWp_ftp_GZF,is_pvalue_ftp_GZF]         = dmwtest(is_ftp_GZF,is_gaussian_GZF,0.05);

% Compute differences and ratios (RMSE, log score, and TLF and FGZ risk scores)
is_ratio_benchmark_rmse  = mean(is_benchmark_rmse)/mean(is_gaussian_rmse);
is_diff_benchmark_lscore = mean(is_benchmark_lscore)-mean(is_gaussian_lscore);
is_perct_benchmark_IC   = mean(is_benchmark_IC);
is_ratio_benchmark_TLF   = mean(is_benchmark_TLF)/mean(is_gaussian_TLF);
is_diff_benchmark_GZF    = mean(is_benchmark_GZF)-mean(is_gaussian_GZF);

is_ratio_onlyGDP_rmse  = mean(is_onlyGDP_rmse)/mean(is_gaussian_rmse);
is_diff_onlyGDP_lscore = mean(is_onlyGDP_lscore)-mean(is_gaussian_lscore);
is_perct_onlyGDP_IC   = mean(is_onlyGDP_IC);
is_ratio_onlyGDP_TLF   = mean(is_onlyGDP_TLF)/mean(is_gaussian_TLF);
is_diff_onlyGDP_GZF    = mean(is_onlyGDP_GZF)-mean(is_gaussian_GZF);

is_ratio_ftp_rmse  = mean(is_ftp_rmse)/mean(is_gaussian_rmse);
is_diff_ftp_lscore = mean(is_ftp_lscore)-mean(is_gaussian_lscore);
is_perct_ftp_IC   = mean(is_ftp_IC);
is_ratio_ftp_TLF   = mean(is_ftp_TLF)/mean(is_gaussian_TLF);
is_diff_ftp_GZF    = mean(is_ftp_GZF)-mean(is_gaussian_GZF);

% Table in lateX format
fprintf('\n')
fprintf('\\begin{table}\n')
fprintf('{\\footnotesize\n')
fprintf('\\begin{threeparttable}\n')
fprintf('\\center\n')
fprintf('\\caption{Accuracy of in-sample forecasts of GDP growth}\n')
fprintf('\\label{tab:isforecast}\n')
fprintf('\\begin{tabular}{lcccccccccc}\n')
fprintf(' \\hline\n ')
fprintf(' \\hline\n')
fprintf(' Model &  & MSFE & & Log-Score & & \\multicolumn{5}{c}{Tail risk scores} \\\\\n')
fprintf(' \\cline{7-11}\n')
fprintf('  &  & & &  & & 5\\%% coverage & & Quantile & & VaR-ES \\\\\n')
fprintf(' \\hline\n')
fprintf(' GDP + CISS & & $\\underset{(%.4f)}{%.4f}$ & & $\\underset{(%.4f)}{%.4f} $& & $\\underset{(%.4f)}{%.4f}$ & & $\\underset{(%.4f)}{%.4f}$ & & $\\underset{(%.4f)}{%.4f}$ \\\\\n', ...
          is_pvalue_benchmark_rmse,  is_ratio_benchmark_rmse, ...
          is_pvalue_benchmark_score, is_diff_benchmark_lscore, ...
          is_pvalue_benchmark_IC,    is_perct_benchmark_IC, ...
          is_pvalue_benchmark_TLF,   is_ratio_benchmark_TLF, ...
          is_pvalue_benchmark_GZF,   is_diff_benchmark_GZF)
fprintf(' only GDP & & $\\underset{(%.4f)}{%.4f}$ & & $\\underset{(%.4f)}{%.4f}$ & & $\\underset{(%.4f)}{%.4f}$ & & $\\underset{(%.4f)}{%.4f}$ & & $\\underset{(%.4f)}{%.4f}$   \\\\\n', ...
          is_pvalue_onlyGDP_rmse,  is_ratio_onlyGDP_rmse, ...
          is_pvalue_onlyGDP_score, is_diff_onlyGDP_lscore, ...
          is_pvalue_onlyGDP_IC,    is_perct_onlyGDP_IC, ...
          is_pvalue_onlyGDP_TLF,   is_ratio_onlyGDP_TLF, ...
          is_pvalue_onlyGDP_GZF,   is_diff_onlyGDP_GZF)
fprintf(' FTP & & $\\underset{(%.4f)}{%.4f}$ & & $\\underset{(%.4f)}{%.4f}$ & & $\\underset{(%.4f)}{%.4f}$ & & $\\underset{(%.4f)}{%.4f}$ & & $\\underset{(%.4f)}{%.4f}$   \\\\\n', ...
          is_pvalue_ftp_rmse,  is_ratio_ftp_rmse, ...
          is_pvalue_ftp_score, is_diff_ftp_lscore, ...
          is_pvalue_ftp_IC,    is_perct_ftp_IC, ...
          is_pvalue_ftp_TLF,   is_ratio_ftp_TLF, ...
          is_pvalue_ftp_GZF,   is_diff_ftp_GZF)
fprintf(' \\hline\n')
fprintf('\\end{tabular}\n')
fprintf('\\begin{tablenotes}[para,flushleft]\n')
fprintf('\\small\n')
fprintf('\\textit{Note:} TBD.\n')
fprintf('\\end{tablenotes}\n')
fprintf('\\end{threeparttable}\n')
fprintf('}\n')
fprintf('\\end{table}\n')
