clear variables; clc;

load('../results/models/benchmark/gibbs_draws.mat','a1gbs','a2gbs');

nd = size(a1gbs,1);

Q1gbs = NaN(2,2,nd);
Q2gbs = NaN(2,2,nd);
Q3gbs = NaN(2,2,nd);

for i=1:nd
pr_11 = normcdf(-a1gbs(i,1));
pr_22 = 1-normcdf(-a1gbs(i,1)-a2gbs(i,1));

Q1gbs(:,:,i) = [   pr_11   1-pr_22
                 1-pr_11     pr_22];

pr_11 = normcdf(-a1gbs(i,2));
pr_22 = 1-normcdf(-a1gbs(i,2)-a2gbs(i,2));

Q2gbs(:,:,i) = [   pr_11   1-pr_22
                 1-pr_11     pr_22];

pr_11 = normcdf(-a1gbs(i,3));
pr_22 = 1-normcdf(-a1gbs(i,3)-a2gbs(i,3));

Q3gbs(:,:,i) = [   pr_11   1-pr_22
                 1-pr_11     pr_22];
end

Q1_quan = quantile(Q1gbs,[0.05 0.16 0.50 0.84 0.95],3);
Q2_quan = quantile(Q2gbs,[0.05 0.16 0.50 0.84 0.95],3);
Q3_quan = quantile(Q3gbs,[0.05 0.16 0.50 0.84 0.95],3);

%
fprintf('\\begin{table}\n')
fprintf('\\begin{threeparttable}\n')
fprintf('\\center\n')
fprintf('\\caption{Estimated transition matrices}\n')
fprintf('\\label{tab_Transition_Matrices}\n')
fprintf('\\begin{tabular}{ccccccccccc}\n')
fprintf(' \\hline\n ')
fprintf(' \\hline\n')
fprintf(' \\multicolumn{3}{c}{Location} & & \\multicolumn{3}{c}{Scale} & & \\multicolumn{3}{c}{Shape} \\\\\n')
fprintf(' \\cline{1-3}\n')
fprintf(' \\cline{5-7}\n')
fprintf(' \\cline{9-11}\n')
fprintf('  &  $s_t^{\\text{lo}}=1$ &  $s_t^{\\text{lo}}=2$ & & & $s_t^{\\text{sc}}=1$ &  $s_t^{\\text{sc}}=2$ & & & $s_t^{\\text{sh}}=1$ &  $s_t^{\\text{sh}}=2$ \\\\\n')
fprintf(' $s_t^{\\text{lo}}=1$ & $\\underset{[%.4f ; %.4f ]}{%.4f}$ & $\\underset{[%.4f ; %.4f ]}{%.4f}$ & & $s_t^{\\text{sc}}=1$  & $\\underset{[%.4f ; %.4f ]}{%.4f}$ & $\\underset{[%.4f ; %.4f ]}{%.4f}$ & & $s_t^{\\text{sh}}=1$  & $\\underset{[%.4f ; %.4f ]}{%.4f}$ & $\\underset{[%.4f ; %.4f ]}{%.4f}$ \\\\\n', ...
          Q2_quan(1,1,2), Q2_quan(1,1,4), Q2_quan(1,1,3),  ...
          Q2_quan(1,2,2), Q2_quan(1,2,4), Q2_quan(1,2,3),  ...
          Q3_quan(1,1,2), Q3_quan(1,1,4), Q3_quan(1,1,3),  ...
          Q3_quan(1,2,2), Q3_quan(1,2,4), Q3_quan(1,2,3),  ...
          Q1_quan(1,1,2), Q1_quan(1,1,4), Q1_quan(1,1,3),  ...
          Q1_quan(1,2,2), Q1_quan(1,2,4), Q1_quan(1,2,3))
fprintf(' $s_t^{\\text{lo}}=2$ & $\\underset{[%.4f ; %.4f ]}{%.4f}$ & $\\underset{[%.4f ; %.4f ]}{%.4f}$ & & $s_t^{\\text{sc}}=2$  & $\\underset{[%.4f ; %.4f ]}{%.4f}$ & $\\underset{[%.4f ; %.4f ]}{%.4f}$ & & $s_t^{\\text{sh}}=2$  & $\\underset{[%.4f ; %.4f ]}{%.4f}$ & $\\underset{[%.4f ; %.4f ]}{%.4f}$ \\\\\n', ...
          Q2_quan(2,1,2), Q2_quan(2,1,4), Q2_quan(2,1,3),  ...
          Q2_quan(2,2,2), Q2_quan(2,2,4), Q2_quan(2,2,3),  ...
          Q3_quan(2,1,2), Q3_quan(2,1,4), Q3_quan(2,1,3),  ...
          Q3_quan(2,2,2), Q3_quan(2,2,4), Q3_quan(2,2,3),  ...
          Q1_quan(2,1,2), Q1_quan(2,1,4), Q1_quan(2,1,3),  ...
          Q1_quan(2,2,2), Q1_quan(2,2,4), Q1_quan(2,2,3))
fprintf(' \\hline\n')
fprintf('\\end{tabular}\n')
fprintf('\\begin{tablenotes}[para,flushleft]\n')
fprintf('\\small\n')
fprintf('\\textit{Note:} Posterior medians and [16th , 64th] percentiles are reported.\n')
fprintf('\\end{tablenotes}\n')
fprintf('\\end{threeparttable}\n')
fprintf('\\end{table}\n')



