
clear variables; close all; clc;

addpath('../library/')

results_root = '../results';

% h-step-ahead forecast
h = 1;                           % Forecast horizon (set to [] if h-step-ahead forecast not desired)
numdraw_h = 5e3;                 % Number of posterior parameter draws to consider

% Beginning of OOS Foreacasting
IntDat    = datetime('04/01/2010','InputFormat','MM/dd/yyyy');

% End of OOS FOrecasting
EndDat    = datetime('10/01/2019','InputFormat','MM/dd/yyyy');

% Time Series of OOS Estimation Date
DatRT     = IntDat:calquarters(1):EndDat;

% Time Series of OOS Date
Dat       = DatRT(1:end-h);

% Memory allocation
oos_benchmark = struct;
oos_onlyGDP   = struct;
oos_ftp       = struct;

oos_benchmark.samples_rmse  = nan(1,length(Dat));
oos_benchmark.samples_score = nan(numdraw_h,length(Dat));
oos_benchmark.samples_IC    = nan(numdraw_h,length(Dat));
oos_benchmark.samples_TLF   = nan(numdraw_h,length(Dat));
oos_benchmark.samples_GZF   = nan(numdraw_h,length(Dat));

oos_onlyGDP.samples_rmse    = nan(1,length(Dat));
oos_onlyGDP.samples_score   = nan(numdraw_h,length(Dat));
oos_onlyGDP.samples_IC      = nan(numdraw_h,length(Dat));
oos_onlyGDP.samples_TLF     = nan(numdraw_h,length(Dat));
oos_onlyGDP.samples_GZF     = nan(numdraw_h,length(Dat));

oos_ftp.samples_rmse        = nan(1,length(Dat));
oos_ftp.samples_score       = nan(numdraw_h,length(Dat));
oos_ftp.samples_IC          = nan(numdraw_h,length(Dat));
oos_ftp.samples_TLF         = nan(numdraw_h,length(Dat));
oos_ftp.samples_GZF         = nan(numdraw_h,length(Dat));

% Out-of-samples results
for i=1:length(Dat)
    
    % benchmark
    oos_benchmark_foreh = load([results_root,'/models/benchmark/real-time/outofsample/',datestr(DatRT(i)),'.mat'],'samples_rmse','samples_score','samples_IC','samples_TLF','samples_GZF','samples_ALS');
    oos_benchmark.samples_rmse(1,i)  = oos_benchmark_foreh.samples_rmse;
    oos_benchmark.samples_score(:,i) = oos_benchmark_foreh.samples_score;
    oos_benchmark.samples_IC(:,i)    = oos_benchmark_foreh.samples_IC;
    oos_benchmark.samples_TLF(:,i)   = oos_benchmark_foreh.samples_TLF;
    oos_benchmark.samples_GZF(:,i)   = oos_benchmark_foreh.samples_GZF;
    
    % only GDP
    oos_onlyGDP_foreh = load([results_root,'/models/onlyGDP/real-time/outofsample/',datestr(DatRT(i)),'.mat'],'samples_rmse','samples_score','samples_IC','samples_TLF','samples_GZF','samples_ALS');
    oos_onlyGDP.samples_rmse(1,i)    = oos_onlyGDP_foreh.samples_rmse;
    oos_onlyGDP.samples_score(:,i)   = oos_onlyGDP_foreh.samples_score;
    oos_onlyGDP.samples_IC(:,i)     = oos_onlyGDP_foreh.samples_IC;
    oos_onlyGDP.samples_TLF(:,i)     = oos_onlyGDP_foreh.samples_TLF;
    oos_onlyGDP.samples_GZF(:,i)     = oos_onlyGDP_foreh.samples_GZF;

    % ftp
    oos_ftp_foreh = load([results_root,'/models/ftp/real-time/outofsample/',datestr(DatRT(i)),'.mat'],'samples_rmse','samples_score','samples_IC','samples_TLF','samples_GZF','samples_ALS');
    oos_ftp.samples_rmse(1,i)        = oos_ftp_foreh.samples_rmse;
    oos_ftp.samples_score(:,i)       = oos_ftp_foreh.samples_score;
    oos_ftp.samples_IC(:,i)          = oos_ftp_foreh.samples_IC;
    oos_ftp.samples_TLF(:,i)         = oos_ftp_foreh.samples_TLF;
    oos_ftp.samples_GZF(:,i)         = oos_ftp_foreh.samples_GZF;
    
end

oos_benchmark_rmse   = sqrt(oos_benchmark.samples_rmse)';
oos_benchmark_lscore = mean(log(oos_benchmark.samples_score))';
oos_benchmark_IC     = mean(oos_benchmark.samples_IC)';
oos_benchmark_TLF    = mean(oos_benchmark.samples_TLF)';
oos_benchmark_GZF    = mean(oos_benchmark.samples_GZF)';

oos_onlyGDP_rmse     = sqrt(oos_onlyGDP.samples_rmse)';
oos_onlyGDP_lscore   = mean(log(oos_onlyGDP.samples_score))';
oos_onlyGDP_IC       = mean(oos_onlyGDP.samples_IC)';
oos_onlyGDP_TLF      = mean(oos_onlyGDP.samples_TLF)';
oos_onlyGDP_GZF      = mean(oos_onlyGDP.samples_GZF)';

oos_ftp_rmse         = sqrt(oos_ftp.samples_rmse)';
lscore               = log(oos_ftp.samples_score); % remove -Inf 
lscore(any(isinf(lscore),2),:) = [];
oos_ftp_lscore       = mean(lscore)';
oos_ftp_IC           = mean(oos_ftp.samples_IC)';
oos_ftp_TLF          = mean(oos_ftp.samples_TLF)';
oos_ftp_GZF          = mean(oos_ftp.samples_GZF)';

% Diebold and Mariano (1995) - West (1996) t-tests
[oos_DMW_benchmark_rmse,oos_GWp_benchmark_rmse,oos_pvalue_benchmark_rmse]    = dmwtest(oos_benchmark_rmse,oos_ftp_rmse,0.05);
[oos_DMW_benchmark_score,oos_GWp_benchmark_score,oos_pvalue_benchmark_score] = dmwtest(oos_benchmark_lscore,oos_ftp_lscore,0.05);
[oos_DMW_benchmark_IC,oos_GWp_benchmark_IC,oos_pvalue_benchmark_IC]          = dmwtest(oos_benchmark_IC,ones(length(Dat),1)*0.05,0.05);
[oos_DMW_benchmark_TLF,oos_GWp_benchmark_TLF,oos_pvalue_benchmark_TLF]       = dmwtest(oos_benchmark_TLF,oos_ftp_TLF,0.05);
[oos_DMW_benchmark_GZF,oos_GWp_benchmark_GZF,oos_pvalue_benchmark_GZF]       = dmwtest(oos_benchmark_GZF,oos_ftp_GZF,0.05);

[oos_DMW_onlyGDP_rmse,oos_GWp_onlyGDP_rmse,oos_pvalue_onlyGDP_rmse]      = dmwtest(oos_onlyGDP_rmse,oos_ftp_rmse,0.05);
[oos_DMW_onlyGDP_score,oos_GWp_onlyGDP_score,oos_pvalue_onlyGDP_score]   = dmwtest(oos_onlyGDP_lscore,oos_ftp_lscore,0.05);
[oos_DMW_onlyGDP_IC,oos_GWp_onlyGDP_IC,oos_pvalue_onlyGDP_IC]            = dmwtest(oos_onlyGDP_IC,ones(length(Dat),1)*0.05,0.05);
[oos_DMW_onlyGDP_TLF,oos_GWp_onlyGDP_TLF,oos_pvalue_onlyGDP_TLF]         = dmwtest(oos_onlyGDP_TLF,oos_ftp_TLF,0.05);
[oos_DMW_onlyGDP_GZF,oos_GWp_onlyGDP_GZF,oos_pvalue_onlyGDP_GZF]         = dmwtest(oos_onlyGDP_GZF,oos_ftp_GZF,0.05);

% Compute differences and ratios (RMSE, log score, and TLF and FGZ risk scores)
oos_ratio_benchmark_rmse  = mean(oos_benchmark_rmse)/mean(oos_ftp_rmse);
oos_diff_benchmark_lscore = mean(oos_benchmark_lscore)-mean(oos_ftp_lscore);
oos_perct_benchmark_IC    = mean(oos_benchmark_IC);
oos_ratio_benchmark_TLF   = mean(oos_benchmark_TLF)/mean(oos_ftp_TLF);
oos_diff_benchmark_GZF    = mean(oos_benchmark_GZF)-mean(oos_ftp_GZF);

oos_ratio_onlyGDP_rmse  = mean(oos_onlyGDP_rmse)/mean(oos_ftp_rmse);
oos_diff_onlyGDP_lscore = mean(oos_onlyGDP_lscore)-mean(oos_ftp_lscore);
oos_perct_onlyGDP_IC    = mean(oos_onlyGDP_IC);
oos_ratio_onlyGDP_TLF   = mean(oos_onlyGDP_TLF)/mean(oos_ftp_TLF);
oos_diff_onlyGDP_GZF    = mean(oos_onlyGDP_GZF)-mean(oos_ftp_GZF);

% Table in lateX format
fprintf('\n')
fprintf('\\begin{table}\n')
fprintf('\\begin{threeparttable}\n')
fprintf('\\center\n')
fprintf('\\label{tab:oosforecast}\n')
fprintf('\\caption{Accuracy of out-of-sample forecasts of GDP growth}\n')
fprintf('\\begin{tabular}{lcccccccccc}\n')
fprintf(' \\hline\n ')
fprintf(' \\hline\n')
fprintf(' \\textbf{Model} &  & \\textbf{MSFE} & & \\textbf{Log-Score} & & \\multicolumn{5}{c}{\\textbf{Tail risk scores}} \\\\\n')
fprintf(' \\cline{7-11}\n')
fprintf('  &  & & &  & & \\textit{5\\%% coverage} & & \\textit{Quantile} & & \\textit{VaR-ES} \\\\\n')
fprintf(' \\hline\n')
fprintf(' GDP + CISS & & $\\underset{(%.4f)}{%.4f}$ & & $\\underset{(%.4f)}{%.4f} $& & $\\underset{(%.4f)}{%.4f}$ & & $\\underset{(%.4f)}{%.4f}$ & & $\\underset{(%.4f)}{%.4f}$ \\\\\n', ...
          oos_pvalue_benchmark_rmse,  oos_ratio_benchmark_rmse, ...
          oos_pvalue_benchmark_score, oos_diff_benchmark_lscore, ...
          oos_pvalue_benchmark_IC,   oos_perct_benchmark_IC, ...
          oos_pvalue_benchmark_TLF,   oos_ratio_benchmark_TLF, ...
          oos_pvalue_benchmark_GZF,   oos_diff_benchmark_GZF)
fprintf(' only GDP & & $\\underset{(%.4f)}{%.4f}$ & & $\\underset{(%.4f)}{%.4f}$ & & $\\underset{(%.4f)}{%.4f}$ & & $\\underset{(%.4f)}{%.4f}$ & & $\\underset{(%.4f)}{%.4f}$   \\\\\n', ...
          oos_pvalue_onlyGDP_rmse,  oos_ratio_onlyGDP_rmse, ...
          oos_pvalue_onlyGDP_score, oos_diff_onlyGDP_lscore, ...
          oos_pvalue_onlyGDP_IC,    oos_perct_onlyGDP_IC, ...
          oos_pvalue_onlyGDP_TLF,   oos_ratio_onlyGDP_TLF, ...
          oos_pvalue_onlyGDP_GZF,   oos_diff_onlyGDP_GZF)
fprintf(' \\hline\n')
fprintf('\\end{tabular}\n')
fprintf('\\begin{tablenotes}[para,flushleft]\n')
fprintf('\\small\n')
fprintf('\\textit{Note:} TBD.\n')
fprintf('\\end{tablenotes}\n')
fprintf('\\end{threeparttable}\n')
fprintf('\\end{table}\n')

